@@ -212,6 +212,9 @@ get_icon_name_from_msg_type (LatexilaBuildMsgType type)
     case LATEXILA_BUILD_MSG_TYPE_BADBOX:
       return "badbox";
 
+    case LATEXILA_BUILD_MSG_TYPE_MAIN_TITLE:
+    case LATEXILA_BUILD_MSG_TYPE_JOB_TITLE:
+    case LATEXILA_BUILD_MSG_TYPE_INFO:
     default:
       return NULL;
     }
@@ -351,14 +354,17 @@ latexila_build_view_class_init (LatexilaBuildViewClass *klass)
    * LatexilaBuildView::jump-to-file:
    * @build_view: a #LatexilaBuildView.
    * @file: the file to open.
-   * @start_line: the line where to jump and the start of the selection, or -1.
-   * @end_line: the end of the selection, or -1.
+   * @start_line: the start of the selection, counting from 0. Or -1 if unset.
+   * @end_line: the end of the selection, counting from 0. Or -1 if unset.
    *
    * The ::jump-to-file signal is emitted when a row in the build view is
    * selected. The row must contain a file, otherwise the signal is not emitted.
    * The file should be opened and presented to the user. If @start_line and
    * @end_line are not -1, jump to the @start_line and select those lines. If
    * @start_line is provided, @end_line is also provided (different than -1).
+   *
+   * The selection should stop at the end of @end_line (not at the start of
+   * @end_line).
    */
   signals[SIGNAL_JUMP_TO_FILE] = g_signal_new ("jump-to-file",
                                                LATEXILA_TYPE_BUILD_VIEW,
@@ -391,6 +397,11 @@ visible_func (GtkTreeModel *model,
     case LATEXILA_BUILD_MSG_TYPE_BADBOX:
       return build_view->priv->show_badboxes;
 
+    case LATEXILA_BUILD_MSG_TYPE_MAIN_TITLE:
+    case LATEXILA_BUILD_MSG_TYPE_JOB_TITLE:
+    case LATEXILA_BUILD_MSG_TYPE_JOB_SUB_COMMAND:
+    case LATEXILA_BUILD_MSG_TYPE_ERROR:
+    case LATEXILA_BUILD_MSG_TYPE_INFO:
     default:
       return TRUE;
     }
@@ -453,6 +464,13 @@ select_row (LatexilaBuildView *build_view,
                       COLUMN_END_LINE, &end_line,
                       -1);
 
+  /* For the signal, we count from 0. */
+  if (start_line > 0)
+    start_line--;
+
+  if (end_line > 0)
+    end_line--;
+
   if (file != NULL)
     {
       g_signal_emit (build_view,
@@ -728,7 +746,7 @@ latexila_build_view_append_single_message (LatexilaBuildView *build_view,
 
   end_line = message->end_line;
   if (message->start_line != -1 && end_line == -1)
-    end_line = message->start_line + 1;
+    end_line = message->start_line;
 
   gtk_tree_store_append (build_view->priv->store, &iter, parent);
   gtk_tree_store_set (build_view->priv->store, &iter,
